************
Library
************

net: Neural Networks
====================
.. automodule:: neurolab.net
    :members:

train: Train Algorithms
=======================
.. automodule:: neurolab.train

error: Error functions
======================
.. automodule:: neurolab.error
    :members:

trans: Transfer functions
=========================
.. automodule:: neurolab.trans
    :members:

init: Initializing functions
============================
.. automodule:: neurolab.init
    :members: